==> ksynaptics_0.1.2.orig.tar.gz: ksynaptics-0.1.2/ksynaptics/src/myframe.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Stefan Kombrink                                 *
 *   katakombi@web.de                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _MYFRAME_H_
#define _MYFRAME_H_

#include <qframe.h>
#include <qevent.h>

class myFrame : public QFrame
{
    Q_OBJECT

public:

    myFrame();
    myFrame(QWidget* parent,const char *name);

    //void setEdges(unsigned int top, unsigned int down, unsigned int left, unsigned int right);
    //void getEdges(unsigned int &top, unsigned int &down, unsigned int &left, unsigned int &right);

public slots:

    //! saves the edge/corner state in circular scrolling mode and redisplays
    void displayCSEdges(int);

protected:
    //! visualizes the active edges / corners of the touch pad
    virtual void paintEvent(QPaintEvent *);
    virtual void mouseMoveEvent(QMouseEvent *);

    //! this variable holds the active edge parameter
    int sTrigger;

    /*
    //! touch pad borders
    static const unsigned int minX=1500;
    static const unsigned int minY=1500;
    static const unsigned int maxX=5500;
    static const unsigned int maxY=4400;

    unsigned int t,d,l,r;
    */
};

#endif

==> ksynaptics_0.2.0.orig.tar.gz: ksynaptics-0.2.0/ksynaptics/src/myframe.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Stefan Kombrink                                 *
 *   katakombi@web.de                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _MYFRAME_H_
#define _MYFRAME_H_

#include <qframe.h>
#include "touchpad.h"

class QPaintEvent;
class QMouseEvent;

class myFrame : public QFrame
{
    Q_OBJECT

public:
    myFrame();
    myFrame(QWidget* parent,const char *name);

public slots:

    //! saves the edge/corner state in circular scrolling mode and redisplays
    void displayPosition(int);

protected:
    //! visualizes the active edges / corners of the touch pad
    virtual void paintEvent(QPaintEvent *);
    virtual void mouseMoveEvent(QMouseEvent *);

    //! this variable holds the active edge parameter
    ScrollTrigger sTrigger;
};

#endif
